// This file is part of the Dynpeak toolbox
// Copyright (C) 2012 - INRIA - Serge Steer
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
function dynpeak_query_pars(win)
  fig=findobj("figure_id", win);
  fig_ud=fig.user_data
  default=fig_ud.dynpeak.detectionparams
  margin_x     = 5;      // Horizontal margin between each elements
  margin_y     = 5;      // Vertical margin between each elements
  button_w     = 70;
  button_h     = 20;
  label_h      = 20;
  label_w      = 250;
  unit_w       = 50;
  edit_w       = 80;

  frame_h     = 10*(label_h+margin_y)+button_h+4*margin_y
  frame_w     = label_h+4*margin_x+max(label_w+edit_w+unit_w,5*(button_w+margin_x))
  axes_w       = 2*margin_x+frame_w;
  axes_h       = 2*margin_y+frame_h;// Frame height
  defaultfont  = "arial"; // Default Font
  
 
  dlg=figure("dockable", "off", ...
               "menubar", "none", ...
               "toolbar", "none", ...
               "infobar_visible", "off",  ...
               "axes_size", [axes_w,axes_h],...
               "figure_name",  _("dynpeak parameters settings"),...
               "default_axes","off",...
               "event_handler_enable", "off",...
               "visible","on",...
               "resize","off");
  
  dlg.background      = addcolor([0.8 0.8 0.8]);
  
  gui=uicontrol( ...
      "parent"              , dlg,...
      "style"               , "frame",...
      "units"               , "pixels",...
      "position"            , [margin_x 0 frame_w frame_h],...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");

  E=[]
  yo=axes_h-button_h;
  y=frame_h-margin_y-label_h
  x1=margin_x;  
  xl=x1+label_h
  xe=xl+label_w+margin_x
  x2=xl+label_w+margin_x
  xu=x2+edit_w+margin_x
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("?"),...
      "units"               , "pixels",...
      "position"            , [x1 y label_h label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on",...
      "tag"                 , "Detection Threshold",...
      "callback"            , "help lhpeaks_settings_detectionthreshold")
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Detection threshold"),...
      "units"               , "pixels",...
      "position"            , [xl y label_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , string(default.detectionthreshold),...
      "units"               , "pixels",...
      "position"            , [xe y edit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "callback"            , "dynpeak_check_pars()", ...
      "tag"                 , "detectionthreshold", ...
      "visible"             , "on")];
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("ng/ml"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  
  y=y-label_h-margin_y
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("?"),...
      "units"               , "pixels",...
      "position"            , [x1 y label_h label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on",...
      "tag"                 , "Variation Coefficient",...
      "callback"            , "help lhpeaks_settings_uncertainty")
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Coefficient of variation"),...
      "units"               , "pixels",...
      "position"            , [xl y label_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  y=y-label_h-margin_y
  x1b=x1+5*margin_x
  label_w2=80
  xeb=x1b+label_w2+margin_x
  edit_w2=x2+edit_w-(x1b+label_w2+margin_x)
  uncertainty=string(diag([1 100])*default.uncertainty)
  u=part(uncertainty(:,1),1:max(length(uncertainty(:,1))))
  for k=2:size(uncertainty,2)
    u=u+', '+part(uncertainty(:,k),1:max(length(uncertainty(:,k))))
  end
  b1=uicontrol(...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Read"),...
      "units"               , "pixels",...
      "position"            , [xeb,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "callback"            , "dynpeak_read_CV()");
  b2=uicontrol(...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Show"),...
      "units"               , "pixels",...
      "position"            , [xeb+button_w+margin_x ,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "callback"            , "dynpeak_show_CV()");
  y=y-label_h-margin_y
  
 
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Range"),...
      "units"               , "pixels",...
      "position"            , [x1b y label_w2 label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , "["+u(1)+"]",...
      "units"               , "pixels",...
      "position"            , [xeb y edit_w2 label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "tag"                 , "Range", ...
      "callback"            , "dynpeak_check_pars()", ...
      "visible"             , "on")];
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("ng/ml"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  y=y-label_h-margin_y
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("CV"),...
      "units"               , "pixels",...
      "position"            , [x1b y label_w-5*margin_x label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , "["+u(2)+"]",...
      "units"               , "pixels",...
      "position"            , [xeb y edit_w2 label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "tag"                 , "CV", ...
      "callback"            , "dynpeak_check_pars()", ...
      "visible"             , "on")];
   uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("%"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
   
  set(b1,"userdata",E($-1:$))
  set(b2,"userdata",E($-1:$))
  
  y=y-label_h-2*margin_y
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Advanced parameters"),...
      "units"               , "pixels",...
      "position"            , [x1 y frame_w-x1-margin_x label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 14,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  
  
  y=y-label_h-margin_y
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("?"),...
      "units"               , "pixels",...
      "position"            , [x1 y label_h label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on",...
      "tag"                 , "Global relative threshold",...
      "callback"            , "help lhpeaks_settings_globalreltol")

  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Global relative threshold"),...
      "units"               , "pixels",...
      "position"            , [xl y label_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , string(default.globalreltol*100),...
      "units"               , "pixels",...
      "position"            , [xe y edit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "callback"            , "dynpeak_check_pars()", ...
      "tag"                 , "globalreltol", ...
      "visible"             , "on")];
   uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("%"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
   
   
   y=y-label_h-margin_y
   uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("?"),...
      "units"               , "pixels",...
      "position"            , [x1 y label_h label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on",...
      "tag"                 , "Local Absolute threshold",...
      "callback"            , "help lhpeaks_settings_localabstol")

  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Local absolute threshold"),...
      "units"               , "pixels",...
      "position"            , [xl y label_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , string(default.localabstol),...
      "units"               , "pixels",...
      "position"            , [xe y edit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "callback"            , "dynpeak_check_pars()", ...
      "tag"                 , "localabstol", ...
      "visible"             , "on")];
   uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("ng/ml"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
   

  
  
  y=y-label_h-margin_y
  
  
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("?"),...
      "units"               , "pixels",...
      "position"            , [x1 y label_h label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on",...
      "tag"                 , "Nominal peaks period",...
      "callback"            , "help lhpeaks_settings_period")
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Nominal peaks period"),...
      "units"               , "pixels",...
      "position"            , [xl y label_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , string(default.period),...
      "units"               , "pixels",...
      "position"            , [xe y edit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "callback"            , "dynpeak_check_pars()", ...
      "tag"                 , "period", ...
      "visible"             , "on")];
   uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("minutes"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
 
   
   
   
  y=y-label_h-margin_y
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("?"),...
      "units"               , "pixels",...
      "position"            , [x1 y label_h label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on",...
      "tag"                 , "Three point threshold",...
      "callback"            , "help lhpeaks_settings_threepointtol")
  uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("Three point threshold"),...
      "units"               , "pixels",...
      "position"            , [xl y label_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "bold", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  E=[E uicontrol( ...
      "parent"              , gui,...
      "style"               , "edit",...
      "string"              , string(default.threepointtol*100),...
      "units"               , "pixels",...
      "position"            , [xe y edit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "callback"            , "dynpeak_check_pars()", ...
      "tag"                 , "threepointtol", ...
      "visible"             , "on")];
   uicontrol( ...
      "parent"              , gui,...
      "style"               , "text",...
      "string"              , _("%"),...
      "units"               , "pixels",...
      "position"            , [xu y unit_w label_h],....
      "fontname"            , defaultfont,...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "fontweight"          , "normal", ...
      "horizontalalignment" , "left", ...
      "background"          , [1 1 1]*0.8, ...
      "visible"             , "on");
  y=y-button_h-2*margin_y
  
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Default"),...
      "units"               , "pixels",...
      "position"            , [x1,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "callback"            , "dynpeak_set(lhpeak_default_params())");
  x2=x1+button_w+margin_x
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Save"),...
      "units"               , "pixels",...
      "position"            , [x2,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "callback"            , "dynpeak_save_pars()");
  x3=x2+button_w+margin_x
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Load"),...
      "units"               , "pixels",...
      "position"            , [x3,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "callback"            , "dynpeak_load_pars()");
  x4=x3+button_w+margin_x
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Ok"),...
      "units"               , "pixels",...
      "position"            , [x4,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "user_data"           , E,...
      "callback"            , "dynpeak_set_parameters("+string(win)+")");
  x5=x4+button_w+margin_x
  uicontrol( ...
      "parent"              , gui,...
      "relief"              , "groove",...
      "style"               , "pushbutton",...
      "string"              , _("Cancel"),...
      "units"               , "pixels",...
      "position"            , [x5,y,button_w button_h],..
      "fontname"            , "arial",...
      "fontunits"           , "points",...
      "fontsize"            , 12,...
      "horizontalalignment" , "center", ...
      "visible"             , "on", ...
      "callback"            , "delete(gcbo.parent.parent)");
  
 
endfunction


